@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2020-2022 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -19,9 +19,7 @@ LoadGroupMenu::LoadGroupMenu(QWidget *parent)
     init();
 }
 
-LoadGroupMenu::~LoadGroupMenu()
-{
-}
+LoadGroupMenu::~LoadGroupMenu() = default;
 
 void LoadGroupMenu::refreshMenu()
 {
